This is a helper tool to back-calculate a number that represents the raw counts in a locus. It is an estimate so one should consider several factors: a) fraglen parameter needs to be accurate; b) fraglen is a constant, so if the original distribution of fragment length was very heterogeneous, it will over/under estimate locus where fragments are shorter or longer than the average. c) If there was a scaling done in the original bigWig, this number will not have a 1 to 1 correspondence with the original number of reads.