Convert a GRanges object with coverage values to estimated counts
Source:R/bwtools.R
gr_coverage_to_read_counts.RdThis method uses estimate_read_counts across a GRanges object and converts the values to read counts.
R/bwtools.R
gr_coverage_to_read_counts.RdThis method uses estimate_read_counts across a GRanges object and converts the values to read counts.